@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-from models import ConfigFile
-from utils import ConfigGroup, autodiscover
-from context import config_context
+from .models import ConfigFile
+from .utils import ConfigGroup, autodiscover
+from .context import config_context
 
 
 __all__ = ("VERSION", "ConfigFile", "ConfigGroup",
